library ask;

import 'package:flutter/material.dart';

export 'package:ask/askRadio.dart';

/// Open a dialog, show the message and buttons, and return a value corresponding to the button's value.
Future<T> ask<T>({String title = '', String message = '', List<AskButton<T>> buttons = const [], @required BuildContext context, defaultValue}) async {
  return await showDialog(
    context: context,
    builder: (context) => AlertDialog(
      title: title == '' ? null : Text(title),
      content: Text(message),
      actions: buttons.map((button) => _getButton(context, button, (){
        Navigator.pop(context, button.value);
      })).toList(),
    ),
  ) ?? defaultValue;
}

Widget _getButton(BuildContext context, AskButton button, Function() action){
  if(button.color == null){
    button.color = Theme.of(context).primaryColor;
  }
  if(button.type == AskButtonType.text){
    return TextButton(
      child: Text(button.text),
      onPressed: action,
      style: ButtonStyle(
        foregroundColor: MaterialStateProperty.all(button.color),
        overlayColor: MaterialStateProperty.all(button.color.withOpacity(0.05)),
      ),
    );
  }
  else if(button.type == AskButtonType.outlined){
    return OutlinedButton(
      child: Text(button.text, style: TextStyle(color: button.color),),
      onPressed: action,
      style: ButtonStyle(
        foregroundColor: MaterialStateProperty.all(button.color),
        overlayColor: MaterialStateProperty.all(button.color.withOpacity(0.05)),
      ),
    );
  }
  else if(button.type == AskButtonType.flat){
    return FlatButton(
      child: Text(button.text),
      onPressed: action,
      color: button.color,
    );
  }
  else if(button.type == AskButtonType.raised){
    return RaisedButton(
      child: Text(button.text),
      onPressed: action,
      color: button.color,
    );
  }
  else return Container();
}

class AskButton<T>{
  final String text;
  Color color;
  final AskButtonType type;
  final T value;

  AskButton({this.color, @required this.text, this.type = AskButtonType.text, @required this.value});
}

enum AskButtonType{
  flat,
  raised,
  text,
  outlined
}